@@ -27,8 +27,9 @@
 #include <klocalizedstring.h>
 #include <klineedit.h>
 #include <kmessagebox.h>
+#include <KPasswordLineEdit>
 
-#include <QtCore/QObject>
+#include <QObject>
 #include <QCheckBox>
 #include <QGroupBox>
 #include <QLabel>
@@ -36,14 +37,13 @@
 #include <QRadioButton>
 #include <QSpinBox>
 #include <QGridLayout>
-
 using namespace KLDAP;
 
 class Q_DECL_HIDDEN LdapConfigWidget::Private
 {
 public:
     Private(LdapConfigWidget *parent)
-        : mParent(parent), mFeatures(W_ALL), mProg(nullptr)
+        : mParent(parent)
     {
         mainLayout = new QGridLayout(mParent);
         mainLayout->setMargin(0);
@@ -61,42 +61,49 @@ public:
     void sendQuery();
     void initWidget();
 
-    LdapConfigWidget *mParent;
-    WinFlags mFeatures;
+    LdapConfigWidget *mParent = nullptr;
+    WinFlags mFeatures = W_ALL;
     QStringList mQResult;
     QString mAttr;
 
-    QLineEdit *mUser;
-    QLineEdit *mPassword;
-    QLineEdit *mHost;
-    QSpinBox  *mPort;
-    QSpinBox *mVersion;
-    QSpinBox *mSizeLimit;
-    QSpinBox *mTimeLimit;
-    QSpinBox *mPageSize;
-    QLineEdit *mDn, *mBindDn, *mRealm;
-    QLineEdit *mFilter;
-    QRadioButton *mAnonymous, *mSimple, *mSASL;
-    QCheckBox *mSubTree;
-    QPushButton *mEditButton;
-    QPushButton *mQueryMech;
-    QRadioButton *mSecNo, *mSecTLS, *mSecSSL;
-    KComboBox *mMech;
+    QLineEdit *mUser = nullptr;
+    KPasswordLineEdit *mPassword = nullptr;
+    QLineEdit *mHost = nullptr;
+    QSpinBox *mPort = nullptr;
+    QSpinBox *mVersion = nullptr;
+    QSpinBox *mSizeLimit = nullptr;
+    QSpinBox *mTimeLimit = nullptr;
+    QSpinBox *mPageSize = nullptr;
+    QLineEdit *mDn = nullptr;
+    QLineEdit *mBindDn = nullptr;
+    QLineEdit *mRealm = nullptr;
+    QLineEdit *mFilter = nullptr;
+    QRadioButton *mAnonymous = nullptr;
+    QRadioButton *mSimple = nullptr;
+    QRadioButton *mSASL = nullptr;
+    QCheckBox *mSubTree = nullptr;
+    QPushButton *mEditButton = nullptr;
+    QPushButton *mQueryMech = nullptr;
+    QRadioButton *mSecNo = nullptr;
+    QRadioButton *mSecTLS = nullptr;
+    QRadioButton *mSecSSL = nullptr;
+    KComboBox *mMech = nullptr;
 
-    bool mCancelled;
-    QProgressDialog *mProg;
+    bool mCancelled = false;
+    QProgressDialog *mProg = nullptr;
 
-    QGridLayout *mainLayout;
+    QGridLayout *mainLayout = nullptr;
 };
 
 void LdapConfigWidget::Private::initWidget()
 {
-    QLabel *label;
+    QLabel *label = nullptr;
 
-    mUser = mPassword = mHost = mDn = mBindDn = mRealm = mFilter = nullptr;
+    mUser = mHost = mDn = mBindDn = mRealm = mFilter = nullptr;
+    mPassword = nullptr;
     mPort = mVersion = mTimeLimit = mSizeLimit = nullptr;
     mAnonymous = mSimple = mSASL = mSecNo = mSecTLS = mSecSSL = nullptr;
-    mEditButton =  mQueryMech = nullptr;
+    mEditButton = mQueryMech = nullptr;
     mPageSize = nullptr;
     mMech = nullptr;
     int row = 0;
@@ -134,9 +141,8 @@ void LdapConfigWidget::Private::initWidget()
 
     if (mFeatures & W_PASS) {
         label = new QLabel(i18n("Password:"), mParent);
-        mPassword = new QLineEdit(mParent);
+        mPassword = new KPasswordLineEdit(mParent);
         mPassword->setObjectName(QStringLiteral("kcfg_ldappassword"));
-        mPassword->setEchoMode(QLineEdit::Password);
 
         mainLayout->addWidget(label, row, 0);
         mainLayout->addWidget(mPassword, row, 1, 1, 3);
@@ -233,7 +239,9 @@ void LdapConfigWidget::Private::initWidget()
         //without host query doesn't make sense
         if (mHost) {
             QPushButton *dnquery = new QPushButton(i18n("Query Server"), mParent);
-            connect(dnquery, SIGNAL(clicked()), mParent, SLOT(queryDNClicked()));
+            connect(dnquery, &QPushButton::clicked, mParent, [this]() {
+                queryDNClicked();
+            });
             mainLayout->addWidget(dnquery, row, 2, 1, 1);
         }
         row++;
@@ -264,33 +272,38 @@ void LdapConfigWidget::Private::initWidget()
         hbox->addWidget(mSecSSL);
         mainLayout->addWidget(btgroup, row, 0, 1, 4);
 
-        connect(mSecNo, SIGNAL(clicked()), mParent, SLOT(setLDAPPort()));
-        connect(mSecTLS, SIGNAL(clicked()), mParent, SLOT(setLDAPPort()));
-        connect(mSecSSL, SIGNAL(clicked()), mParent, SLOT(setLDAPSPort()));
+        connect(mSecNo, &QRadioButton::clicked, mParent, [this]() {
+            setLDAPPort();
+        });
+        connect(mSecTLS, &QRadioButton::clicked, mParent, [this]() {
+            setLDAPPort();
+        });
+        connect(mSecSSL, &QRadioButton::clicked, mParent, [this]() {
+            setLDAPSPort();
+        });
 
         mSecNo->setChecked(true);
         row++;
     }
 
     if (mFeatures & W_AUTHBOX) {
-
-        QGroupBox *authbox =
-            new QGroupBox(i18n("Authentication"), mParent);
+        QGroupBox *authbox
+            = new QGroupBox(i18n("Authentication"), mParent);
         QVBoxLayout *vbox = new QVBoxLayout;
         authbox->setLayout(vbox);
         QHBoxLayout *hbox = new QHBoxLayout;
         vbox->addLayout(hbox);
 
-        mAnonymous =
-            new QRadioButton(i18nc("@option:radio anonymous authentication", "Anonymous"), authbox);
+        mAnonymous
+            = new QRadioButton(i18nc("@option:radio anonymous authentication", "Anonymous"), authbox);
         mAnonymous->setObjectName(QStringLiteral("kcfg_ldapanon"));
         hbox->addWidget(mAnonymous);
-        mSimple =
-            new QRadioButton(i18nc("@option:radio simple authentication", "Simple"), authbox);
+        mSimple
+            = new QRadioButton(i18nc("@option:radio simple authentication", "Simple"), authbox);
         mSimple->setObjectName(QStringLiteral("kcfg_ldapsimple"));
         hbox->addWidget(mSimple);
-        mSASL =
-            new QRadioButton(i18nc("@option:radio SASL authentication", "SASL"), authbox);
+        mSASL
+            = new QRadioButton(i18nc("@option:radio SASL authentication", "SASL"), authbox);
         mSASL->setObjectName(QStringLiteral("kcfg_ldapsasl"));
         hbox->addWidget(mSASL);
 
@@ -298,9 +311,8 @@ void LdapConfigWidget::Private::initWidget()
         vbox->addLayout(hbox);
         label = new QLabel(i18n("SASL mechanism:"), authbox);
         hbox->addWidget(label);
-        mMech = new KComboBox(false, authbox);
+        mMech = new KComboBox(authbox);
         mMech->setObjectName(QStringLiteral("kcfg_ldapsaslmech"));
-        mMech->setEditable(true);
         mMech->addItem(QStringLiteral("DIGEST-MD5"));
         mMech->addItem(QStringLiteral("GSSAPI"));
         mMech->addItem(QStringLiteral("PLAIN"));
@@ -310,14 +322,22 @@ void LdapConfigWidget::Private::initWidget()
         if (mHost) {
             mQueryMech = new QPushButton(i18n("Query Server"), authbox);
             hbox->addWidget(mQueryMech);
-            connect(mQueryMech, SIGNAL(clicked()), mParent, SLOT(queryMechClicked()));
+            connect(mQueryMech, &QPushButton::clicked, mParent, [this]() {
+                queryMechClicked();
+            });
         }
 
         mainLayout->addWidget(authbox, row, 0, 2, 4);
 
-        connect(mAnonymous, SIGNAL(toggled(bool)), mParent, SLOT(setAnonymous(bool)));
-        connect(mSimple, SIGNAL(toggled(bool)), mParent, SLOT(setSimple(bool)));
-        connect(mSASL, SIGNAL(toggled(bool)), mParent, SLOT(setSASL(bool)));
+        connect(mAnonymous, &QRadioButton::toggled, mParent, [this](bool b) {
+            setAnonymous(b);
+        });
+        connect(mSimple, &QRadioButton::toggled, mParent, [this](bool b) {
+            setSimple(b);
+        });
+        connect(mSASL, &QRadioButton::toggled, mParent, [this](bool b) {
+            setSASL(b);
+        });
 
         mAnonymous->setChecked(true);
     }
@@ -343,13 +363,15 @@ void LdapConfigWidget::Private::sendQuery()
     qCDebug(LDAP_LOG) << "sendQuery url:" << _url.toDisplayString();
 
     LdapSearch search;
-    connect(&search, SIGNAL(data(KLDAP::LdapSearch*,KLDAP::LdapObject)),
-            mParent, SLOT(loadData(KLDAP::LdapSearch*,KLDAP::LdapObject)));
-    connect(&search, SIGNAL(result(KLDAP::LdapSearch*)),
-            mParent, SLOT(loadResult(KLDAP::LdapSearch*)));
+    connect(&search, &LdapSearch::data, mParent, [this](KLDAP::LdapSearch *s, const KLDAP::LdapObject &obj) {
+        loadData(s, obj);
+    });
+    connect(&search, &LdapSearch::result, mParent, [this](KLDAP::LdapSearch *s) {
+        loadResult(s);
+    });
 
     if (!search.search(_url)) {
-        KMessageBox::error(mParent, search.errorString());
+        KMessageBox::error(mParent, search.errorString(), i18n("Check server"));
         return;
     }
 
@@ -393,7 +415,7 @@ void LdapConfigWidget::Private::queryDNClicked()
     mAttr = QStringLiteral("namingcontexts");
     sendQuery();
     if (!mQResult.isEmpty()) {
-        mDn->setText(mQResult.first());
+        mDn->setText(mQResult.constFirst());
     }
 }
 
@@ -403,10 +425,10 @@ void LdapConfigWidget::Private::loadData(LdapSearch *, const LdapObject &object)
     mProg->setValue(mProg->value() + 1);
     LdapAttrMap::ConstIterator end(object.attributes().constEnd());
     for (LdapAttrMap::ConstIterator it = object.attributes().constBegin();
-            it != end; ++it) {
+         it != end; ++it) {
         LdapAttrValue::ConstIterator end2((*it).constEnd());
         for (LdapAttrValue::ConstIterator it2 = (*it).constBegin();
-                it2 != end2; ++it2) {
+             it2 != end2; ++it2) {
             mQResult.push_back(QString::fromUtf8(*it2));
         }
     }
@@ -509,13 +531,14 @@ void LdapConfigWidget::Private::setLDAPSPort()
 }
 
 LdapConfigWidget::LdapConfigWidget(QWidget *parent, Qt::WindowFlags fl)
-    : QWidget(parent, fl), d(new Private(this))
+    : QWidget(parent, fl)
+    , d(new Private(this))
 {
 }
 
-LdapConfigWidget::LdapConfigWidget(LdapConfigWidget::WinFlags flags,
-                                   QWidget *parent, Qt::WindowFlags fl)
-    : QWidget(parent, fl), d(new Private(this))
+LdapConfigWidget::LdapConfigWidget(LdapConfigWidget::WinFlags flags, QWidget *parent, Qt::WindowFlags fl)
+    : QWidget(parent, fl)
+    , d(new Private(this))
 {
     d->mFeatures = flags;
 
@@ -557,7 +580,7 @@ LdapServer LdapConfigWidget::server() const
         _server.setBindDn(d->mBindDn->text());
     }
     if (d->mPassword) {
-        _server.setPassword(d->mPassword->text());
+        _server.setPassword(d->mPassword->password());
     }
     if (d->mRealm) {
         _server.setRealm(d->mRealm->text());
@@ -665,13 +688,13 @@ QString LdapConfigWidget::user() const
 void LdapConfigWidget::setPassword(const QString &password)
 {
     if (d->mPassword) {
-        d->mPassword->setText(password);
+        d->mPassword->setPassword(password);
     }
 }
 
 QString LdapConfigWidget::password() const
 {
-    return d->mPassword ? d->mPassword->text() : QString();
+    return d->mPassword ? d->mPassword->password() : QString();
 }
 
 void LdapConfigWidget::setBindDn(const QString &binddn)
